Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2014-10-19 21:09:58 +0400
committerCampbell Barton <ideasman42@gmail.com>2014-10-19 21:09:58 +0400
commit4c86271bd9652c19f72728686452fb126ca67016 (patch)
treebc5843e37a022825db57362e13088fa628deda07 /release/scripts/freestyle
parent2103cf9355d55a740d387e6c0e3e0e7ca280decd (diff)
Revert "Fix for rB61a330baca0f: Changed SVG file encoding from UTF-16 to UTF-8."
This reverts commit 490f2aeb8247463a7ea1a86a3a8c4246fcf45f23.
Diffstat (limited to 'release/scripts/freestyle')
-rw-r--r--release/scripts/freestyle/modules/svg_export.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/release/scripts/freestyle/modules/svg_export.py b/release/scripts/freestyle/modules/svg_export.py
index 92149b703c1..09566730891 100644
--- a/release/scripts/freestyle/modules/svg_export.py
+++ b/release/scripts/freestyle/modules/svg_export.py
@@ -27,7 +27,7 @@ et.register_namespace("inkscape", "http://www.inkscape.org/namespaces/inkscape")
et.register_namespace("sodipodi", "http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd")
# use utf-8 here to keep ElementTree happy
svg_primitive = """<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<svg xmlns="http://www.w3.org/2000/svg" version="1.1" width="{:d}" height="{:d}">
</svg>"""
@@ -128,7 +128,7 @@ class SVGPathShader(StrokeShader):
# write SVG to file
indent_xml(root)
- tree.write(self.filepath, encoding='UTF-8', xml_declaration=True)
+ tree.write(self.filepath, encoding='UTF-16', xml_declaration=True)
# - Fill export - #
class ShapeZ(BinaryPredicate1D):
@@ -222,7 +222,7 @@ class SVGFillShader(StrokeShader):
# write SVG to file
indent_xml(root)
- tree.write(self.filepath, encoding='UTF-8', xml_declaration=True)
+ tree.write(self.filepath, encoding='UTF-16', xml_declaration=True)
def indent_xml(elem, level=0, indentsize=4):
@@ -302,4 +302,4 @@ def write_animation(filepath, frame_begin, fps=25):
# write SVG to file
indent_xml(root)
- tree.write(filepath, encoding='UTF-8', xml_declaration=True)
+ tree.write(filepath, encoding='UTF-16', xml_declaration=True)
@@ -27,7 +27,7 @@ et.register_namespace("inkscape", "http://www.inkscape.org/namespaces/inkscape")
et.register_namespace("sodipodi", "http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd")
-# use utf-8 here to keep ElementTree happy
+# use utf-8 here to keep ElementTree happy, end result is utf-16
svg_primitive = """<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<svg xmlns="http://www.w3.org/2000/svg" version="1.1" width="{:d}" height="{:d}">